==> mozc_1.5.1090.102.orig.tar.gz: mozc-1.5.1090.102/languages/pinyin/english_dictionary_interface.h <==
// Copyright 2010-2012, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

// English dictionary interface for ibus-mozc-pinyin

#ifndef MOZC_LANGUAGES_PINYIN_ENGLISH_DICTIONARY_INTERFACE_H_
#define MOZC_LANGUAGES_PINYIN_ENGLISH_DICTIONARY_INTERFACE_H_

#include <string>
#include <vector>

namespace mozc {
namespace pinyin {
namespace english {

class EnglishDictionaryInterface {
 public:
  virtual ~EnglishDictionaryInterface() {}

  // Get suggestions.
  virtual bool GetSuggestions(
      const string &prefix, vector<string> *output) const = 0;

  // Learns word to add unknown word or to boost a word priority.
  virtual void LearnWord(const string &word) = 0;
};

}  // namespace english
}  // namespace pinyin
}  // namespace mozc

// MOZC_LANGUAGES_PINYIN_ENGLISH_DICTIONARY_INTERFACE_H_
#endif

==> mozc_1.6.1187.102.orig.tar.gz: mozc-1.6.1187.102/languages/pinyin/english_dictionary_interface.h <==
// Copyright 2010-2012, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

// English dictionary interface for ibus-mozc-pinyin

#ifndef MOZC_LANGUAGES_PINYIN_ENGLISH_DICTIONARY_INTERFACE_H_
#define MOZC_LANGUAGES_PINYIN_ENGLISH_DICTIONARY_INTERFACE_H_

#include <string>
#include <vector>

namespace mozc {
namespace pinyin {
namespace english {

class EnglishDictionaryInterface {
 public:
  virtual ~EnglishDictionaryInterface() {}

  // Gets English words starts with prefix.
  virtual void GetSuggestions(
      const string &prefix, vector<string> *output) const = 0;

  // Learns word to add unknown word or to boost a word priority.
  virtual bool LearnWord(const string &word) = 0;
};

}  // namespace english
}  // namespace pinyin
}  // namespace mozc

// MOZC_LANGUAGES_PINYIN_ENGLISH_DICTIONARY_INTERFACE_H_
#endif
